@@ -79,7 +79,6 @@ class PagedFilteredTableView(SingleTableView):
             self.request.GET['practice_values'] and \
             'page' not in self.request.GET:
             page = self.request.session['page']
-            logger.debug(f"override {page=}")
         else:
             page = self.request.GET.get('page', 1)
             self.set_page(page)
@@ -133,26 +132,19 @@ class PagedFilteredTableView(SingleTableView):
         """
 
         self.ip = request.META.get("REMOTE_ADDR")  # this ip is used to store
-        logger.info(f"get comes from {self.ip=}")
         self.request.session.setdefault('page', 1)
         self.request.session.setdefault('subset', 'a')
         self.session.practice_list = self.load_practice_words()
         # if page not sent in request, use the previous
         self.session.page = self.request.session['page']
         self.session.subset = self.request.session['subset']
-        logger.debug(f"begin get {self.session.page=}")
-        logger.debug(f"begin get {self.session.subset=}")
 
         if 'page' in request.GET:
             self.set_page(request.GET.get("page"))
 
-        logger.debug(f"resetting page to {self.session.page}")
-        logger.debug(f"{request.GET=}")
-
         if any([let in request.GET for let in 'abcdefghijklmnopqrstuvwxyz']):
             for let in request.GET:
                 if len(let) == 1:  # really pressed a letter button?
-                    logger.info(f"set subset selection to {let}")
                     self.set_subset(let)
                     self.set_page(1)
 
@@ -165,17 +157,14 @@ class PagedFilteredTableView(SingleTableView):
 
         # if "synonyms" in request.GET:
         #    self.session.synonyms = not self.session.synonyms
-        #    logger.info(f"synonyms in request")
         #    # add synonyms column to table
 
         if "addword" in request.GET:
-            logger.info("editword in request")
             return redirect("admin/elo/word")
             # go to admin/Word
 
         # if "example" in request.GET:
         #    self.session.examples = not self.session.examples
-        #    logger.info("example in request")
         # add example column to table
 
         self.make_collection_changes(self.request.GET)
@@ -217,8 +206,6 @@ class WordTableView(PagedFilteredTableView):
 
         # first remove deleted words
         # so this would delete anything in the table which is not in the practice list
-        logger.info(f"{self.ip=}")
-        logger.info(Practice.objects.filter(ip=self.ip).values_list("word_id", flat=True))
         Practice.objects.filter(ip=self.ip).exclude(word_id__in=self.session.practice_list).delete()
 
         # add records one by one from the include list
@@ -241,7 +228,6 @@ class WordTableView(PagedFilteredTableView):
         :return: None
         """
         words = g.get('practice_values', '').split(',')
-        logger.info(f"{words=}")
         try:
             words = list(map(int, words))
         except ValueError:
@@ -257,7 +243,6 @@ class WordTableView(PagedFilteredTableView):
 
     def get_table_data(self):
         data = self.get_queryset().values()
-        logger.debug(f'len of data={len(data)}')
 
         for record in data:
             if self.session.synonyms:
